CCL: ccl_test_core Namespace Reference

CCL

Functions
ccl_test_core Namespace Reference

## Functions
def | test_parameters_valid_input ()
def | test_parameters_missing ()
def | test_parameters_spelling ()
def | test_parameters_mgrowth ()

## Function Documentation

## ◆ test_parameters_mgrowth()

def ccl_test_core.test_parameters_mgrowth | ( |  | ) |

    Check that valid modified growth inputs are allowed, and invalid ones are
    rejected.

## ◆ test_parameters_missing()

def ccl_test_core.test_parameters_missing | ( |  | ) |

    Check that errors are raised when compulsory parameters are missing, but
    not when non-compulsory ones are.

## ◆ test_parameters_spelling()

def ccl_test_core.test_parameters_spelling | ( |  | ) |

    Check for misspelled parameters arguments.

## ◆ test_parameters_valid_input()

def ccl_test_core.test_parameters_valid_input | ( |  | ) |

    Check that valid parameter arguments are accepted.